Files
open-webui/backend/open_webui/models
Classic298 113a64ad1a perf: speed up one-word chat search (#32268)
Chat search checks the whole query and each word in it separately. With a single word those are the same check, so every chat got searched twice. It is now searched once, with the same results. On PostgreSQL with 2164 chats (533 MB of chat data) a one-word search is about 40% faster:

| search | before | after |
|---|---|---|
| proxy | 6.0 s | 3.6 s |
| opnsense | 6.1 s | 3.8 s |
| no match | 5.4 s | 3.0 s |

Refs #32266
2026-10-12 23:32:52 +04:00
..
2026-10-09 15:07:43 +04:00
2026-10-12 22:14:04 +04:00
2026-10-05 12:17:25 +04:00
2026-10-05 14:01:02 +04:00
2026-10-12 17:29:04 +04:00
2026-10-08 14:30:07 +04:00
2026-10-05 12:17:25 +04:00
2026-10-08 19:36:27 +04:00
2026-10-09 18:37:55 +04:00
2026-10-09 18:37:55 +04:00
2026-10-05 14:35:15 +04:00
2026-10-10 23:18:09 +04:00
2026-07-24 01:54:36 -04:00
2026-10-12 17:57:02 +04:00
2026-10-09 17:05:53 +04:00
2026-10-09 17:05:53 +04:00
2026-10-08 01:09:29 +04:00
2026-07-31 17:41:14 -04:00
2026-10-09 16:17:11 +04:00
2026-10-05 14:01:02 +04:00
2026-10-08 14:30:07 +04:00
2026-10-09 16:31:34 +04:00
2026-10-09 18:37:55 +04:00
2026-10-09 18:37:55 +04:00